unit PermanentModule;

interface

uses
    SysUtils,
    Classes,
    SxPmtDataModule,
    SxProvider,
    SxIconList,
    Menus,
    SxPopupMenu, DB, DBTables, SyncObjs, SxNamespaceUtils, Dialogs,
    ImgList, Controls;

type
  TPermanentModuleForm = class(TSxPermanentModule)
    ByHandProvider: TSxByHandProvider;
    qryCategories: TQuery;
    qryCategoriescategory: TStringField;
    ToolbarMenu: TSxGrainMenu;
    ImageList24x24: TImageList;
    ImageList16x16: TImageList;
    miToggleShellView: TSxGrainMenuItem;
    procedure ByHandProviderPopulate(Sender: TSxByHandProvider;
      DataGrain: TSxByHandDataGrain; GrainList: TList);
    procedure SxPermanentModuleCreate(Sender: TObject);
    procedure SxPermanentModuleDestroy(Sender: TObject);
    procedure miToggleShellViewClickGrain(Sender: TSxMenuItem;
      DataGrain: TSxCustomDataGrain);
  private
    FUseSysShellView: Boolean;
    { Private declarations }
  protected
    { Protected declarations }
    BioCS:TCriticalSection;
  public
    { Public declarations }
    procedure Lock;
    procedure UnLock;
    property UseSysShellView:Boolean read FUseSysShellView write FUseSysShellView;
  end;

function PermanentDataModule:TPermanentModuleForm;

implementation

uses ShellUI, SxShellFolder, ShlObj;

{$WRITEABLECONST ON}
const
  __PermanentModule:TPermanentModuleForm=nil;
{$WRITEABLECONST OFF}

function PermanentDataModule:TPermanentModuleForm;
begin
  if __PermanentModule=nil then
     TPermanentModuleForm.Create(nil);
  Result:=__PermanentModule;
end;

{$R *.DFM}

procedure TPermanentModuleForm.ByHandProviderPopulate(
  Sender: TSxByHandProvider; DataGrain: TSxByHandDataGrain;
  GrainList: TList);
var
  tempGrain:TSxCustomDataGrain;
begin
  Lock;
  try
    if DataGrain.IsRoot then
    begin
      qryCategories.First;
      while not qryCategories.Eof do
      begin
        tempGrain:=ByHandProvider.CreateGrainInstance;
        tempGrain.GrainType:=gtFolder;
        tempGrain.Name:=qryCategories.FieldByName('category').AsString;
        tempGrain.GrainID:=qryCategories.FieldByName('category').AsString;
        GrainList.Add(tempGrain);
        qryCategories.Next;
      end;
    end;
  finally
    UnLock;
  end;
end;

procedure TPermanentModuleForm.Lock;
begin
  BioCS.Acquire;
end;

procedure TPermanentModuleForm.UnLock;
begin
  BioCS.Release;
end;

procedure TPermanentModuleForm.SxPermanentModuleCreate(Sender: TObject);
begin
  BioCS:=TCriticalSection.Create;
  __PermanentModule:=Self;
  UseSysShellView:=True;
end;

procedure TPermanentModuleForm.SxPermanentModuleDestroy(Sender: TObject);
begin
  FreeAndNil(BioCS);
end;

procedure TPermanentModuleForm.miToggleShellViewClickGrain(
  Sender: TSxMenuItem; DataGrain: TSxCustomDataGrain);
begin
  UseSysShellView:=not UseSysShellView;
  Sender.ShellFolder.ShellView.ShellBrowser.BrowseObject(ByHandProvider.RootPidl, SBSP_SAMEBROWSER);
end;

initialization
  RegisterPermanentModuleClass(TPermanentModuleForm);
end.









 
 
